@@ -1,5 +1,3 @@
-
-
 import importlib
 import os
 
@@ -15,11 +13,14 @@ user_log_dir_path = _dirs.user_log_dir
 user_config_dir_path = _dirs.user_config_dir
 
 for d in [
-        user_data_dir_path, user_cache_dir_path,
-        user_log_dir_path, user_config_dir_path]:
+    user_data_dir_path,
+    user_cache_dir_path,
+    user_log_dir_path,
+    user_config_dir_path,
+]:
     if not os.path.exists(d):
         os.makedirs(d, exist_ok=True)
 
 
 def get_copy_path(module_str):
-    return os.path.join(user_data_dir_path, module_str) + f'.{app_version}.pkl'
+    return os.path.join(user_data_dir_path, module_str) + f".{app_version}.pkl"
