@@ -1,4 +1,3 @@
-
 import importlib
 import os
 import pickle
@@ -16,38 +15,41 @@ from pygame_menu.widgets import *
 
 from primaryschool.dirs import *
 from primaryschool.locale import _
-from primaryschool.resource import (default_font, default_font_path,
-                                    get_default_font, get_resource_path)
+from primaryschool.resource import (
+    default_font,
+    default_font_path,
+    get_default_font,
+    get_resource_path,
+)
 from primaryschool.settings import *
 from primaryschool.subjects import subjects
 
 app_description_t = _("app_description_t")
 
 
-class SaveMenu():
-    def __init__(
-            self,
-            ps):
+class SaveMenu:
+    def __init__(self, ps):
         self.ps = ps
         self.surface = self.ps.surface
-        self.title = _('Save game?')
+        self.title = _("Save game?")
         self._menu = self.ps.get_default_menu(self.title)
         self.save = False
 
     def add_widgets(self):
 
         self._menu.add.button(
-            _('Save and return'),
+            _("Save and return"),
             self.save_the_game,
-            font_name=self.ps.font_path)
+            font_name=self.ps.font_path,
+        )
         self._menu.add.button(
-            _('Continue'),
-            self.continue_the_game,
-            font_name=self.ps.font_path)
+            _("Continue"), self.continue_the_game, font_name=self.ps.font_path
+        )
         self._menu.add.button(
-            _('Return to main menu'),
+            _("Return to main menu"),
             self.to_main_menu,
-            font_name=self.ps.font_path)
+            font_name=self.ps.font_path,
+        )
 
     def to_main_menu(self):
         self.ps.main_menu._menu.full_reset()
@@ -63,14 +65,13 @@ class SaveMenu():
         self._menu.disable()
 
 
-class ContributorsMenu():
-    def __init__(
-            self,
-            ps):
+class ContributorsMenu:
+    def __init__(self, ps):
         self.ps = ps
-        self.title = _('Contributors & Sponsors')
+        self.title = _("Contributors & Sponsors")
         self._menu = self.ps.get_default_menu(
-            self.title, onclose=pygame_menu.events.EXIT)
+            self.title, onclose=pygame_menu.events.EXIT
+        )
         self._font = get_default_font(15)
         self._head_font = get_default_font(18)
         self.return_background_color = (200, 200, 255, 200)
@@ -78,81 +79,82 @@ class ContributorsMenu():
     def add_widgets(self):
         contributors_table = self._menu.add.table()
         contributors_table.default_cell_padding = 5
-        contributors_table.default_row_background_color = 'white'
+        contributors_table.default_row_background_color = "white"
         contributors_table.add_row(
-            [_('Contributors'), _('name'), ' ', _('Sponsors'), _('name')],
-            cell_font=self._head_font)
+            [_("Contributors"), _("name"), " ", _("Sponsors"), _("name")],
+            cell_font=self._head_font,
+        )
 
         _len = list(range(max(len(app_contributors), len(app_sponsors))))
         for l, c, s in zip_longest(_len, app_contributors, app_sponsors):
-            c, s = c or ' ', s or ' '
+            c, s = c or " ", s or " "
             contributors_table.add_row(
-                [l + 1, c, ' ', l + 1, s],
-                cell_font=self._font)
+                [l + 1, c, " ", l + 1, s], cell_font=self._font
+            )
 
         self._menu.add.button(
-            _('Return to main menu'),
+            _("Return to main menu"),
             pygame_menu.events.BACK,
             font_name=self.ps.font_path,
             background_color=self.return_background_color,
-            float=True, align=pygame_menu.locals.ALIGN_RIGHT)
+            float=True,
+            align=pygame_menu.locals.ALIGN_RIGHT,
+        )
 
 
-class AboutMenu():
-    def __init__(
-            self,
-            ps):
+class AboutMenu:
+    def __init__(self, ps):
 
         self.ps = ps
-        self.title = _('About')
+        self.title = _("About")
         self._menu = self.ps.get_default_menu(self.title)
         self.app_name_font = get_default_font(50)
         self.app_version_font = get_default_font(20)
         self.app_description_font = get_default_font(22)
         self.app_url_font = get_default_font(20)
-        self.app_author_font = self.app_contributors_font = \
-            get_default_font(20)
+        self.app_author_font = self.app_contributors_font = get_default_font(
+            20
+        )
         self.contributors_menu = ContributorsMenu(self.ps)
         self._label_font = get_default_font(32)
 
     def add_widgets(self):
         self._menu.add.label(
-            app_name, max_char=-1,
-            font_name=self.app_name_font)
+            app_name, max_char=-1, font_name=self.app_name_font
+        )
         self._menu.add.label(
-            app_version, max_char=-1,
-            font_name=self.app_version_font)
+            app_version, max_char=-1, font_name=self.app_version_font
+        )
         self._menu.add.label(
-            app_description_t, max_char=-1,
-            font_name=self.app_description_font)
-        self._menu.add.url(
-            app_url, font_name=self.app_url_font)
+            app_description_t, max_char=-1, font_name=self.app_description_font
+        )
+        self._menu.add.url(app_url, font_name=self.app_url_font)
         self._menu.add.label(
-            _('Author'), max_char=-1,
-            font_name=self._label_font)
+            _("Author"), max_char=-1, font_name=self._label_font
+        )
         self._menu.add.label(
-            app_author, max_char=-1,
-            font_name=self.app_author_font)
+            app_author, max_char=-1, font_name=self.app_author_font
+        )
 
         self.contributors_menu.add_widgets()
 
         self._menu.add.button(
-            _('Contributors & Sponsors'),
+            _("Contributors & Sponsors"),
             self.contributors_menu._menu,
-            font_name=self._label_font)
+            font_name=self._label_font,
+        )
 
         self._menu.add.button(
-            _('Return to main menu'),
+            _("Return to main menu"),
             pygame_menu.events.BACK,
-            font_name=self.ps.font_path)
+            font_name=self.ps.font_path,
+        )
 
 
-class PlayMenu():
-    def __init__(
-            self,
-            ps):
+class PlayMenu:
+    def __init__(self, ps):
         self.ps = ps
-        self.title = _('Play Game')
+        self.title = _("Play Game")
         self.player_name = self.ps.player_name
         self.player_name_text_input = None
         self._menu = self.ps.get_default_menu(self.title)
@@ -176,81 +178,87 @@ class PlayMenu():
     def set_player_name(self, name):
         self.player_name = self.ps.player_name = name
         if self.player_name_text_input:
-            self.player_name_text_input.set_value(
-                self.player_name)
+            self.player_name_text_input.set_value(self.player_name)
 
     def get_player_name(self):
         return self.player_name
 
     def add_widgets(self):
         self.player_name_text_input = self._menu.add.text_input(
-            title=_('Name :'),
+            title=_("Name :"),
             default=self.get_player_name(),
-            font_name=self.ps.font_path)
+            font_name=self.ps.font_path,
+        )
 
         self.subject_dropselect = self._menu.add.dropselect(
-            title=_('Subject :'),
-            items=[(s.name_t, index) for index, s in
-                   enumerate(self.subjects)],
+            title=_("Subject :"),
+            items=[(s.name_t, index) for index, s in enumerate(self.subjects)],
             font_name=self.ps.font_path,
             default=0,
             selection_box_bgcolor=self.selection_box_bgcolor,
-            placeholder=_('Select a Subject'),
-            onchange=self.on_subject_dropselect_change
+            placeholder=_("Select a Subject"),
+            onchange=self.on_subject_dropselect_change,
         )
         self.subject_game_dropselect = self._menu.add.dropselect(
-            title=_('Game :'),
-            items=[(g.name_t, index) for index, g in
-                   enumerate(self.subject_games)],
+            title=_("Game :"),
+            items=[
+                (g.name_t, index) for index, g in enumerate(self.subject_games)
+            ],
             font_name=self.ps.font_path,
             default=0,
             selection_box_bgcolor=self.selection_box_bgcolor,
-            placeholder=_('Select a game'),
-            onchange=self.on_subject_game_dropselect_change
+            placeholder=_("Select a game"),
+            onchange=self.on_subject_game_dropselect_change,
         )
 
         self.difficulty_dropselect = self._menu.add.dropselect(
-            title=_('Difficulty :'),
-            items=[(d, index) for index, d in
-                   enumerate(self.subject_games[0].difficulties)],
+            title=_("Difficulty :"),
+            items=[
+                (d, index)
+                for index, d in enumerate(self.subject_games[0].difficulties)
+            ],
             font_name=self.ps.font_path,
             default=0,
             selection_box_bgcolor=self.selection_box_bgcolor,
-            placeholder=_('Select a difficulty'),
-            onchange=self.on_difficulty_dropselect_change
+            placeholder=_("Select a difficulty"),
+            onchange=self.on_difficulty_dropselect_change,
         )
         self.update_selection_box_width()
         self.set_difficulty_index()
 
         self._menu.add.button(
-            _('Play'),
-            self.play_btn_onreturn,
-            font_name=self.ps.font_path)
+            _("Play"), self.play_btn_onreturn, font_name=self.ps.font_path
+        )
 
         self.continue_button = self._menu.add.button(
-            _('Continue'),
+            _("Continue"),
             self.continue_btn_onreturn,
-            font_name=self.ps.font_path)
+            font_name=self.ps.font_path,
+        )
         self.update_continue_button()
 
         self._menu.add.button(
-            _('Return to main menu'),
+            _("Return to main menu"),
             pygame_menu.events.BACK,
-            font_name=self.ps.font_path)
+            font_name=self.ps.font_path,
+        )
 
         self.help_lael = self._menu.add.label(
-            '', font_name=self.help_lael_font)
+            "", font_name=self.help_lael_font
+        )
         self.update_help_lael()
 
     def update_selection_box_width(self):
         for ds in [
-                self.subject_dropselect,
-                self.subject_game_dropselect,
-                self.difficulty_dropselect]:
+            self.subject_dropselect,
+            self.subject_game_dropselect,
+            self.difficulty_dropselect,
+        ]:
 
-            ds._selection_box_width = max(
-                [b.get_width() for b in ds._option_buttons]
-            ) + ds._selection_box_inflate[0]
+            ds._selection_box_width = (
+                max([b.get_width() for b in ds._option_buttons])
+                + ds._selection_box_inflate[0]
+            )
             ds._make_selection_drop()
             ds.render()
 
@@ -268,14 +276,17 @@ class PlayMenu():
 
     def update_subject_game_dropselect(self):
         self.subject_game_dropselect.update_items(
-            [(g.name_t, index) for index, g in enumerate(
-                self.subject.games)])
+            [(g.name_t, index) for index, g in enumerate(self.subject.games)]
+        )
         self.subject_game_dropselect.set_value(self.subject_game_index)
 
     def update_difficulty_dropselect(self):
         self.difficulty_dropselect.update_items(
-            [(d, index) for index, d in enumerate(
-                self.subject_game.difficulties)])
+            [
+                (d, index)
+                for index, d in enumerate(self.subject_game.difficulties)
+            ]
+        )
         self.difficulty_dropselect.set_value(self.difficulty_index)
 
     def update_help_lael(self):
@@ -308,51 +319,57 @@ class PlayMenu():
 
     def set_subject_game_index(self, index=0):
         self.subject_game_index = self.ps.subject_game_index = index
-        self.subject_game = self.ps.subject_game = \
-            self.subject.games[self.subject_game_index]
+        self.subject_game = self.ps.subject_game = self.subject.games[
+            self.subject_game_index
+        ]
         self.update_continue_button()
         self.set_difficulty_index()
         self.update_help_lael()
 
     def set_difficulty_index(self, index=0):
-        self.difficulty_index = \
-            self.ps.difficulty_index = index if index != 0 else \
-            self.subject_game.default_difficulty_index
+        self.difficulty_index = self.ps.difficulty_index = (
+            index if index != 0 else self.subject_game.default_difficulty_index
+        )
         self.update_difficulty_dropselect()
 
 
-class MainMenu():
+class MainMenu:
     def __init__(self, ps):
         self.ps = ps
-        self.title = _('Primary School')
+        self.title = _("Primary School")
         self._menu = self.ps.get_default_menu(self.title)
         self.play_menu = self.ps.play_menu
         self.about_menu = self.ps.about_menu
 
     def add_widgets(self):
         self._menu.add.button(
-            _('Play'), self.ps.play_menu._menu,
-            font_name=self.ps.font_path,)
+            _("Play"),
+            self.ps.play_menu._menu,
+            font_name=self.ps.font_path,
+        )
         self._menu.add.button(
-            _('About'), self.ps.about_menu._menu,
-            font_name=self.ps.font_path,)
+            _("About"),
+            self.ps.about_menu._menu,
+            font_name=self.ps.font_path,
+        )
         self._menu.add.button(
-            _('Quit'), pygame_menu.events.EXIT,
-            font_name=self.ps.font_path,)
+            _("Quit"),
+            pygame_menu.events.EXIT,
+            font_name=self.ps.font_path,
+        )
 
 
-class PrimarySchool():
+class PrimarySchool:
     def __init__(self):
         pygame.init()
         self.running = True
-        self.surface = pygame.display.set_mode(
-            (0, 0), pygame.RESIZABLE)
+        self.surface = pygame.display.set_mode((0, 0), pygame.RESIZABLE)
         self.w_width, self.w_height = self.surface.get_size()
         self.w_width_of_2 = self.w_width / 2
         self.w_height_of_2 = self.w_height / 2
         self.w_centrex_y = [self.w_width_of_2, self.w_height]
         self.FPS = 30
-        self.player_name = _('default_name')
+        self.player_name = _("default_name")
         self.clock = pygame.time.Clock()
         self.subjects = subjects
         self.subject_games = self.subjects[0].games
@@ -375,10 +392,10 @@ class PrimarySchool():
         self.save_menu.add_widgets()
         self.main_menu.add_widgets()
 
-    def set_bg_img(self, src_name='0x1.png'):
+    def set_bg_img(self, src_name="0x1.png"):
         self.bg_img = BaseImage(
-            get_resource_path(src_name),
-            pygame_menu.baseimage.IMAGE_MODE_FILL)
+            get_resource_path(src_name), pygame_menu.baseimage.IMAGE_MODE_FILL
+        )
 
     def get_bg_img(self):
         if not self.bg_img:
@@ -391,9 +408,8 @@ class PrimarySchool():
         theme.title_bar_style = pygame_menu.widgets.MENUBAR_STYLE_NONE
         theme.background_color = self.get_bg_img()
         return pygame_menu.Menu(
-            title,
-            self.w_width, self.w_height,
-            theme=theme, **kwargs)
+            title, self.w_width, self.w_height, theme=theme, **kwargs
+        )
 
     def clear_screen(self):
         self.surface.fill((255, 255, 255))
