@@ -1,5 +1,4 @@
-
-class PsKeyCode():
+class PsKeyCode:
     def __init__(self):
         pass
 
@@ -10,36 +9,31 @@ class PsKeyCode():
         return 97 <= code <= 122
 
     def keycode_in_alpha(self, code):
-        return \
-            self.keycode_in_alpha_lower(code) or \
-            self.keycode_in_alpha_upper(code)
+        return self.keycode_in_alpha_lower(
+            code
+        ) or self.keycode_in_alpha_upper(code)
 
     def keycode_in_num_neg(self, code):
-        return \
-            self.keycode_in_pure_num(code) or \
-            self.keycode_in_hyphen(code)
+        return self.keycode_in_pure_num(code) or self.keycode_in_hyphen(code)
 
     def keycode_in_num_float(self, code):
-        return \
-            self.keycode_in_pure_num(code) or \
-            self.keycode_in_dot(code)
+        return self.keycode_in_pure_num(code) or self.keycode_in_dot(code)
 
     def keycode_in_pure_num(self, code):
         return 48 <= code <= 57
 
     def keycode_in_num(self, code):
-        return \
-            self.keycode_in_pure_num(code) or \
-            self.keycode_in_hyphen(code) or \
-            self.keycode_in_dot(code)
+        return (
+            self.keycode_in_pure_num(code)
+            or self.keycode_in_hyphen(code)
+            or self.keycode_in_dot(code)
+        )
 
     def keycode_in_dot(self, code):
         return code == 46
 
     def keycode_in_alpha_num(self, code):
-        return \
-            self.keycode_in_num(code) or \
-            self.keycode_in_alpha(code)
+        return self.keycode_in_num(code) or self.keycode_in_alpha(code)
 
     def keycode_in_space(self, code):
         return code == 32
@@ -48,4 +42,4 @@ class PsKeyCode():
         return code == 45
 
     def keycode_in_return(self, code):
-        return code == 0xd
+        return code == 0xD
